@@ -1,27 +1,21 @@
 use clap::{clap_app, value_t};
 use parse_int::parse;
+use std::fs::File;
+use std::io::{BufReader, Read};
 use std::time::Duration;
 
+use ross_dsl::Parser;
 use ross_protocol::interface::serial::Serial;
 use ross_protocol::protocol::{Protocol, BROADCAST_ADDRESS};
 
-use crate::event_type::EventType;
-use crate::get_devices::get_devices;
-use crate::get_programmer::get_programmer;
-use crate::ross_configurator::*;
-use crate::send_event::send_event;
-use crate::set_device_address::set_device_address;
-use crate::upgrade_config::upgrade_config;
-use crate::upgrade_firmware::upgrade_firmware;
-
-mod event_type;
-mod get_devices;
-mod get_programmer;
-mod ross_configurator;
-mod send_event;
-mod set_device_address;
-mod upgrade_config;
-mod upgrade_firmware;
+use ross_configurator::event_type::EventType;
+use ross_configurator::get_devices::get_devices;
+use ross_configurator::get_programmer::get_programmer;
+use ross_configurator::ross_configurator::*;
+use ross_configurator::send_event::send_event;
+use ross_configurator::set_device_address::set_device_address;
+use ross_configurator::upgrade_config::upgrade_config;
+use ross_configurator::upgrade_firmware::upgrade_firmware;
 
 fn main() -> Result<(), ConfiguratorError> {
     let matches = clap_app!(ross_configurator =>
@@ -49,7 +43,7 @@ fn main() -> Result<(), ConfiguratorError> {
         )
         (@subcommand set_device_address =>
             (about: "Sets a specific device's address")
-            (@arg NEW_ADDRESS: -n --new-address +required +takes_value "New device address")
+            (@arg NEW_ADDRESS: -n --("new-address") +required +takes_value "New device address")
             (@arg ADDRESS: -a --address +required +takes_value "Recipient device address")
         )
         (@subcommand send_event =>
@@ -90,11 +84,13 @@ fn main() -> Result<(), ConfiguratorError> {
         Protocol::new(BROADCAST_ADDRESS, serial)
     };
 
-    let programmer = get_programmer(&mut protocol)?;
-
     match matches.subcommand() {
-        ("get_programmer", _) => Ok(()),
+        ("get_programmer", _) => {
+            get_programmer(&mut protocol)?;
+            Ok(())
+        }
         ("get_devices", _) => {
+            let programmer = get_programmer(&mut protocol)?;
             get_devices(&mut protocol, &programmer)?;
             Ok(())
         }
@@ -110,6 +106,7 @@ fn main() -> Result<(), ConfiguratorError> {
                 }
             };
 
+            let programmer = get_programmer(&mut protocol)?;
             let devices = get_devices(&mut protocol, &programmer)?;
 
             upgrade_firmware(&mut protocol, &programmer, &devices, firmware, address)?;
@@ -128,9 +125,31 @@ fn main() -> Result<(), ConfiguratorError> {
                 }
             };
 
+            let file = match File::open(config) {
+                Ok(file) => file,
+                Err(err) => {
+                    return Err(ConfiguratorError::IOError(err));
+                }
+            };
+
+            let mut source_code = String::new();
+
+            let mut reader = BufReader::new(file);
+            reader
+                .read_to_string(&mut source_code)
+                .map_err(|err| ConfiguratorError::IOError(err))?;
+
+            let config = Parser::parse(&source_code).map_err(|err| {
+                eprintln!("Parsing failed with error:");
+                eprintln!("{}", err);
+
+                ConfiguratorError::ParserError(err)
+            })?;
+
+            let programmer = get_programmer(&mut protocol)?;
             let devices = get_devices(&mut protocol, &programmer)?;
 
-            upgrade_config(&mut protocol, &programmer, &devices, config, address)?;
+            upgrade_config(&mut protocol, &programmer, &devices, &config, address)?;
 
             Ok(())
         }
@@ -153,6 +172,7 @@ fn main() -> Result<(), ConfiguratorError> {
                 }
             };
 
+            let programmer = get_programmer(&mut protocol)?;
             let devices = get_devices(&mut protocol, &programmer)?;
 
             set_device_address(&mut protocol, &programmer, &devices, new_address, address)?;
@@ -165,6 +185,7 @@ fn main() -> Result<(), ConfiguratorError> {
             let event = value_t!(sub_matches, "EVENT", EventType).unwrap_or_else(|e| e.exit());
             let data = sub_matches.values_of("DATA").unwrap().collect();
 
+            get_programmer(&mut protocol)?;
             send_event(&mut protocol, event, data)?;
 
             Ok(())
